[Zope3-checkins] CVS: Zope3/src/zope/app/services/tests - test_field.py:1.3

Steve Alexander steve@cat-box.net
Thu, 9 Jan 2003 12:29:18 -0500


Update of /cvs-repository/Zope3/src/zope/app/services/tests
In directory cvs.zope.org:/tmp/cvs-serv16296/src/zope/app/services/tests

Modified Files:
	test_field.py 
Log Message:
Renamed ComponentLocation field to ComponentPath field in preparation
for a true ComponentLocation field.


=== Zope3/src/zope/app/services/tests/test_field.py 1.2 => 1.3 ===
--- Zope3/src/zope/app/services/tests/test_field.py:1.2	Wed Dec 25 09:13:20 2002
+++ Zope3/src/zope/app/services/tests/test_field.py	Thu Jan  9 12:28:46 2003
@@ -11,7 +11,7 @@
 # FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
 """Tests for ComponentLocation field.
 
 $Id$
 """
@@ -21,7 +21,7 @@
 from zope.app.traversing import traverse
 from zope.schema.interfaces import ValidationError
 from zope.interface import Interface
-from zope.app.services.field import ComponentLocation
+from zope.app.services.field import ComponentPath
 
 class I1(Interface):  pass
 
@@ -40,7 +40,7 @@
 
         folder2 = traverse(self.rootFolder, 'folder2')
 
-        field = ComponentLocation(type=I1)
+        field = ComponentPath(type=I1)
         field = field.bind(folder2)
 
         field.validate(u'/folder1/c')
@@ -11,7 +11,7 @@
 #
 ##############################################################################
-"""Tests for ComponentLocation field.
+"""Tests for ComponentPath field.
 
 $Id$